cmake_minimum_required(
	# 3.3: IN_LIST
	VERSION 3.3...${CMAKE_VERSION})

set(Z80_known_components Static Shared)
set(Z80_component_Static NO)
set(Z80_component_Shared NO)

foreach(Z80_component IN LISTS ${CMAKE_FIND_PACKAGE_NAME}_FIND_COMPONENTS)
	if(Z80_component IN_LIST Z80_known_components)
		set(Z80_component_${Z80_component} YES)
	else()
		set(	${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE
			"`${Z80_component}` is not a valid component.")

		set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
		return()
	endif()
endforeach()

if(Z80_component_Static AND Z80_component_Shared)
	set(	${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE
		"`Static` and `Shared` are mutually exclusive.")

	set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
	return()
endif()

set(Z80_Static_targets "${CMAKE_CURRENT_LIST_DIR}/Z80StaticTargets.cmake")
set(Z80_Shared_targets "${CMAKE_CURRENT_LIST_DIR}/Z80SharedTargets.cmake")

macro(Z80_load_targets type)
	if(NOT EXISTS "${Z80_${type}_targets}")
		set(	${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE
			"`${type}` libraries were requested but not found.")

		set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
		return()
	endif()

	include(CMakeFindDependencyMacro)
	find_dependency(Zeta)
	include("${Z80_${type}_targets}")
endmacro()

if(Z80_component_Static)
	Z80_load_targets(Static)
elseif(Z80_component_Shared)
	Z80_load_targets(Shared)
elseif(DEFINED Z80_SHARED_LIBS AND Z80_SHARED_LIBS)
	Z80_load_targets(Shared)
elseif(DEFINED Z80_SHARED_LIBS AND NOT Z80_SHARED_LIBS)
	Z80_load_targets(Static)
elseif(BUILD_SHARED_LIBS)
	if(EXISTS "${Z80_Shared_targets}")
		Z80_load_targets(Shared)
	else()
		Z80_load_targets(Static)
	endif()
else()
	if(EXISTS "${Z80_Static_targets}")
		Z80_load_targets(Static)
	else()
		Z80_load_targets(Shared)
	endif()
endif()
